pub enum DecodeError {
InvalidByte(u8),
UnexpectedEnd,
UnexpectedEscape(EscapedHex, char),
LowercaseHex(EscapedHex),
InvalidHex(EscapedHex),
}Expand description
An error trying to decode a tick-encoded string.
Variants
InvalidByte(u8)
Encountered an invalid byte in the string. This could either by a
non-ASCII byte or an ASCII byte that requires escaping (see
requires_escape).
UnexpectedEnd
Reached the end of the string following a backtick (`). A backtick must be followed by either another backtick or a 2-digit hex value.
UnexpectedEscape(EscapedHex, char)
Tried to decode a 2-digit hex value, but the value does not require
escaping (see requires_escape).
LowercaseHex(EscapedHex)
Tried to decode a 2-digit hex value, but the hex value contained
the values [a-f]. Escaped hex values must use [A-F].
InvalidHex(EscapedHex)
Tried to decode a 2-digit hex value, but an invalid hex digit
was found. Escaped hex values must use the characters [0-9A-F].